import React from 'react';
export declare type MultiProviderProps = React.PropsWithChildren<{
    providers: React.ReactElement[];
}>;
/**
 * MultiProvider
 * A component that allows chaining multiple providers as children.
 * @param {MultiProviderProps} props - Props for the MultiProvider component.
 * @param {React.ReactElement[]} props.providers - An array of React elements representing the providers.
 * @returns {React.ReactElement} - The rendered MultiProvider component.
 * @example
 * // Example usage of MultiProvider
 * <MultiProvider
 *   providers={[
 *     <Provider1 key='provider1' />,
 *     <Provider2 key='provider2' />,
 *     <Provider3 key='provider3' />
 *   ]}
 * >
 *   <App />
 * </MultiProvider>
 */
declare const MultiProvider: React.FC<MultiProviderProps>;
export default MultiProvider;
